Creates a validated list of keyword strings for use in manuscript metadata.
The returned object can be passed to manuscript_meta().
Creates a validated list of keyword strings for use in manuscript metadata.
The returned object can be passed to manuscript_meta().