Outputs a markdown header with Quarto's {.appendix} class via cat(),
suitable for use in Quarto code chunks with #| output: asis. This marks
the section as an appendix in Quarto's cross-reference system.
Outputs a markdown header with Quarto's {.appendix} class via cat(),
suitable for use in Quarto code chunks with #| output: asis. This marks
the section as an appendix in Quarto's cross-reference system.