Outputs a note line starting with *Note:* via cat(), suitable for use
in Quarto code chunks with #| output: asis. This allows figure notes to
be rendered as formatted markdown in the final document.
Outputs a note line starting with *Note:* via cat(), suitable for use
in Quarto code chunks with #| output: asis. This allows figure notes to
be rendered as formatted markdown in the final document.