Combines authors, affiliations, and optional metadata fields into a single
serializable object. Performs cross-validation: every affiliation ID
referenced by an author must have a matching affiliation() object.
Usage
manuscript_meta(
authors,
affiliations = list(),
keywords = NULL,
jel = NULL,
acknowledgements = NULL,
report_number = NULL,
funding = NULL,
data_availability = NULL,
code_availability = NULL
)Arguments
A list of
typstR_authorobjects created byauthor().- affiliations
A list of
typstR_affiliationobjects created byaffiliation(). Defaults to an empty list.- keywords
Character vector of keywords, or
NULL.- jel
Character vector of JEL classification codes, or
NULL.- acknowledgements
Character scalar acknowledgement text, or
NULL.- report_number
Character scalar report number, or
NULL.- funding
Character scalar funding statement, or
NULL.- data_availability
Character scalar data availability statement, or
NULL.- code_availability
Character scalar code availability statement, or
NULL.
Examples
authors <- list(
author(
name = "Ada Lovelace",
affiliation = "econ",
corresponding = TRUE
)
)
affiliations <- list(
affiliation(
id = "econ",
name = "Institute for Advanced Policy Studies",
country = "Austria"
)
)
manuscript_meta(
authors = authors,
affiliations = affiliations,
keywords = keywords("trade", "policy"),
jel = jel_codes("F10"),
report_number = report_number("WP 001")
)
#> <typstR_meta> 1 author(s), 1 affiliation(s)