Renders a Quarto document using the Quarto CLI after running the shared environment validation checks that typstR uses before rendering.
Usage
render_pub(
input = NULL,
output_format = NULL,
quiet = FALSE,
open = interactive()
)Arguments
- input
Path to a
.qmdfile, a directory containing a.qmdfile, orNULLto look in the current directory.- output_format
Quarto output format name (e.g.,
"typstR-typst"). IfNULL, uses the format specified in the document YAML.- quiet
If
TRUE, suppresses Quarto output. Defaults toFALSE.- open
If
TRUE, opens the rendered PDF in the system viewer. Defaults toTRUEin interactive sessions.